@@ -28,10 +28,13 @@ class SentryClient(object):
         checksum = construct_checksum(**kwargs)
 
         if conf.THRASHING_TIMEOUT and conf.THRASHING_LIMIT:
-            cache_key = 'sentry:%s:%s' % (kwargs.get('class_name'), checksum)
+            cache_key = 'sentry:%s:%s' % (kwargs.get('class_name') or '', checksum)
             added = cache.add(cache_key, 1, conf.THRASHING_TIMEOUT)
-            if not added and cache.incr(cache_key) > conf.THRASHING_LIMIT:
-                return
+            try:
+                if not added and cache.incr(cache_key) > conf.THRASHING_LIMIT:
+                    return
+            except KeyError:
+                pass
 
         for filter_ in get_filters():
             kwargs = filter_(None).process(kwargs) or kwargs
